@@ -139,7 +139,7 @@ ggscatterstats <- function(data,
   # adding a subtitle with statistical results
   if (results.subtitle) {
     # convert entered stats type to a standard notation
-    type <- statsExpressions::stats_type_switch(type)
+    type <- stats_type_switch(type)
 
     # relevant arguments for statistical tests
     .f.args <- list(
@@ -222,7 +222,7 @@ ggscatterstats <- function(data,
 
   if (marginal) {
     # installed?
-    insight::check_if_installed("ggside", minimum_version = "0.1.2")
+    check_if_installed("ggside", minimum_version = "0.1.2")
 
     # adding marginal distributions
     plot <- plot +
@@ -265,40 +265,35 @@ ggscatterstats <- function(data,
 #'
 #' # basic function call
 #' grouped_ggscatterstats(
-#'   data = filter(movies_long, genre == "Comedy" | genre == "Drama"),
-#'   x = length,
-#'   y = rating,
-#'   type = "robust",
-#'   grouping.var = genre,
+#'   data             = filter(movies_long, genre == "Comedy" | genre == "Drama"),
+#'   x                = length,
+#'   y                = rating,
+#'   type             = "robust",
+#'   grouping.var     = genre,
 #'   ggplot.component = list(geom_rug(sides = "b"))
 #' )
 #'
 #' # using labeling
 #' # (also show how to modify basic plot from within function call)
 #' grouped_ggscatterstats(
-#'   data = filter(ggplot2::mpg, cyl != 5),
-#'   x = displ,
-#'   y = hwy,
-#'   grouping.var = cyl,
-#'   type = "robust",
-#'   label.var = manufacturer,
+#'   data             = filter(ggplot2::mpg, cyl != 5),
+#'   x                = displ,
+#'   y                = hwy,
+#'   grouping.var     = cyl,
+#'   type             = "robust",
+#'   label.var        = manufacturer,
 #'   label.expression = hwy > 25 & displ > 2.5,
 #'   ggplot.component = scale_y_continuous(sec.axis = dup_axis())
 #' )
 #'
 #' # labeling without expression
-#'
 #' grouped_ggscatterstats(
-#'   data = filter(
-#'     movies_long,
-#'     rating == 7,
-#'     genre %in% c("Drama", "Comedy")
-#'   ),
-#'   x = budget,
-#'   y = length,
-#'   grouping.var = genre,
-#'   bf.message = FALSE,
-#'   label.var = "title",
+#'   data            = filter(movies_long, rating == 7, genre %in% c("Drama", "Comedy")),
+#'   x               = budget,
+#'   y               = length,
+#'   grouping.var    = genre,
+#'   bf.message      = FALSE,
+#'   label.var       = "title",
 #'   annotation.args = list(tag_levels = "a")
 #' )
 #' @export
