@@ -7,13 +7,6 @@
 #' for within-subjects designs with statistical details included in the plot as
 #' a subtitle.
 #'
-#' @note
-#'
-#' To carry out Bayesian analysis for ANOVA designs, you will need to install
-#' the development version of `BayesFactor` (`0.9.12-4.3`). You can download it
-#' by running:
-#' `remotes::install_github("richarddmorey/BayesFactor/pkg/BayesFactor")`.
-#'
 #' @inheritParams ggbetweenstats
 #' @param point.path,centrality.path Logical that decides whether individual data
 #'   points and means, respectively, should be connected using `geom_path`. Both
@@ -36,29 +29,31 @@
 #'
 #' @examples
 #' \donttest{
-#' # setup
-#' set.seed(123)
-#' library(ggstatsplot)
-#' library(dplyr, warn.conflicts = FALSE)
+#' if (require("PMCMRplus")) {
+#'   # setup
+#'   set.seed(123)
+#'   library(ggstatsplot)
+#'   library(dplyr, warn.conflicts = FALSE)
 #'
-#' # two groups (*t*-test)
-#' ggwithinstats(
-#'   data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
-#'   x = condition,
-#'   y = desire
-#' )
+#'   # two groups (*t*-test)
+#'   ggwithinstats(
+#'     data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+#'     x    = condition,
+#'     y    = desire
+#'   )
 #'
-#' # more than two groups (anova)
-#' library(WRS2)
+#'   # more than two groups (anova)
+#'   library(WRS2)
 #'
-#' ggwithinstats(
-#'   data = WineTasting,
-#'   x = Wine,
-#'   y = Taste,
-#'   type = "r",
-#'   outlier.tagging = TRUE,
-#'   outlier.label = Taster
-#' )
+#'   ggwithinstats(
+#'     data            = WineTasting,
+#'     x               = Wine,
+#'     y               = Taste,
+#'     type            = "r",
+#'     outlier.tagging = TRUE,
+#'     outlier.label   = Taster
+#'   )
+#' }
 #' }
 #' @export
 
@@ -139,7 +134,7 @@ ggwithinstats <- function(data,
   if (!quo_is_null(enquo(outlier.label))) ensym(outlier.label)
 
   # convert entered stats type to a standard notation
-  type <- statsExpressions::stats_type_switch(type)
+  type <- stats_type_switch(type)
 
   # creating a dataframe
   data %<>%
@@ -156,9 +151,9 @@ ggwithinstats <- function(data,
   # add a logical column indicating whether a point is or is not an outlier
   data %<>%
     outlier_df(
-      x = {{ x }},
-      y = {{ y }},
-      outlier.coef = outlier.coef,
+      x             = {{ x }},
+      y             = {{ y }},
+      outlier.coef  = outlier.coef,
       outlier.label = outlier.label
     )
 
@@ -167,30 +162,34 @@ ggwithinstats <- function(data,
   # test to run; depends on the no. of levels of the independent variable
   test <- ifelse(nlevels(data %>% pull({{ x }})) < 3, "t", "anova")
 
-  if (results.subtitle && insight::check_if_installed("afex")) {
+  if (results.subtitle && check_if_installed("afex")) {
     # relevant arguments for statistical tests
     .f.args <- list(
-      data = data,
-      x = as_string(x),
-      y = as_string(y),
+      data         = data,
+      x            = as_string(x),
+      y            = as_string(y),
       effsize.type = effsize.type,
-      conf.level = conf.level,
-      k = k,
-      tr = tr,
-      paired = TRUE,
-      bf.prior = bf.prior,
-      nboot = nboot,
-      top.text = caption
+      conf.level   = conf.level,
+      k            = k,
+      tr           = tr,
+      paired       = TRUE,
+      bf.prior     = bf.prior,
+      nboot        = nboot,
+      top.text     = caption
     )
 
-    .f <- function_switch(test)
+    # styler: off
+    .f          <- function_switch(test)
     subtitle_df <- eval_f(.f, !!!.f.args, type = type)
-    subtitle <- if (!is.null(subtitle_df)) subtitle_df$expression[[1]]
+    subtitle    <- if (!is.null(subtitle_df)) subtitle_df$expression[[1]]
+    # styler: on
 
     # preparing the Bayes factor message
     if (type == "parametric" && bf.message) {
+      # styler: off
       caption_df <- eval_f(.f, !!!.f.args, type = "bayes")
-      caption <- if (!is.null(caption_df)) caption_df$expression[[1]]
+      caption    <- if (!is.null(caption_df)) caption_df$expression[[1]]
+      # styler: on
     }
   }
 
@@ -223,11 +222,11 @@ ggwithinstats <- function(data,
     # applying the labels to tagged outliers with `ggrepel`
     plot <- plot +
       exec(
-        .fn = ggrepel::geom_label_repel,
-        data = ~ filter(.x, isanoutlier),
-        mapping = aes(x = {{ x }}, y = {{ y }}, label = outlier.label),
+        .fn                = ggrepel::geom_label_repel,
+        data               = ~ filter(.x, isanoutlier),
+        mapping            = aes(x = {{ x }}, y = {{ y }}, label = outlier.label),
         min.segment.length = 0,
-        inherit.aes = FALSE,
+        inherit.aes        = FALSE,
         !!!outlier.label.args
       )
   }
@@ -237,15 +236,15 @@ ggwithinstats <- function(data,
   # add labels for mean values
   if (isTRUE(centrality.plotting)) {
     plot <- centrality_ggrepel(
-      plot = plot,
-      data = data,
-      x = {{ x }},
-      y = {{ y }},
-      k = k,
-      type = statsExpressions::stats_type_switch(centrality.type),
-      tr = tr,
-      centrality.path = centrality.path,
-      centrality.path.args = centrality.path.args,
+      plot                  = plot,
+      data                  = data,
+      x                     = {{ x }},
+      y                     = {{ y }},
+      k                     = k,
+      type                  = stats_type_switch(centrality.type),
+      tr                    = tr,
+      centrality.path       = centrality.path,
+      centrality.path.args  = centrality.path.args,
       centrality.point.args = centrality.point.args,
       centrality.label.args = centrality.label.args
     )
@@ -256,30 +255,31 @@ ggwithinstats <- function(data,
   if (isTRUE(pairwise.comparisons) && test == "anova") {
     # creating dataframe with pairwise comparison results
     mpc_df <- pairwise_comparisons(
-      data = data,
-      x = {{ x }},
-      y = {{ y }},
-      type = type,
-      tr = tr,
-      paired = TRUE,
+      data            = data,
+      x               = {{ x }},
+      y               = {{ y }},
+      type            = type,
+      tr              = tr,
+      paired          = TRUE,
       p.adjust.method = p.adjust.method,
-      k = k
+      k               = k
     )
 
     # adding the layer for pairwise comparisons
     plot <- ggsignif_adder(
-      plot = plot,
-      mpc_df = mpc_df,
-      data = data,
-      x = {{ x }},
-      y = {{ y }},
+      plot             = plot,
+      mpc_df           = mpc_df,
+      data             = data,
+      x                = {{ x }},
+      y                = {{ y }},
       pairwise.display = pairwise.display,
-      ggsignif.args = ggsignif.args
+      ggsignif.args    = ggsignif.args
     )
 
     # preparing the caption for pairwise comparisons test
     caption <- pairwise_caption(
       caption,
+      bf.message = ifelse(type == "parametric", bf.message, FALSE),
       unique(mpc_df$test.details),
       ifelse(type == "bayes", "all", pairwise.display)
     )
@@ -289,16 +289,16 @@ ggwithinstats <- function(data,
 
   # specifying annotations and other aesthetic aspects for the plot
   aesthetic_addon(
-    plot = plot,
-    x = data %>% pull({{ x }}),
-    xlab = xlab %||% as_name(x),
-    ylab = ylab %||% as_name(y),
-    title = title,
-    subtitle = subtitle,
-    caption = caption,
-    ggtheme = ggtheme,
-    package = package,
-    palette = palette,
+    plot             = plot,
+    x                = data %>% pull({{ x }}),
+    xlab             = xlab %||% as_name(x),
+    ylab             = ylab %||% as_name(y),
+    title            = title,
+    subtitle         = subtitle,
+    caption          = caption,
+    ggtheme          = ggtheme,
+    package          = package,
+    palette          = palette,
     ggplot.component = ggplot.component
   )
 }
@@ -323,25 +323,24 @@ ggwithinstats <- function(data,
 #'
 #' @examples
 #' \donttest{
-#' # to get reproducible results from bootstrapping
-#' set.seed(123)
-#' library(ggstatsplot)
-#' library(dplyr, warn.conflicts = FALSE)
-#' library(ggplot2)
+#' if (require("PMCMRplus")) {
+#'   # to get reproducible results from bootstrapping
+#'   set.seed(123)
+#'   library(ggstatsplot)
+#'   library(dplyr, warn.conflicts = FALSE)
+#'   library(ggplot2)
 #'
-#' # the most basic function call
-#' grouped_ggwithinstats(
-#'   data = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
-#'   x = condition,
-#'   y = desire,
-#'   grouping.var = gender,
-#'   type = "np", # non-parametric test
-#'   # additional modifications for **each** plot using `{ggplot2}` functions
-#'   ggplot.component = scale_y_continuous(
-#'     breaks = seq(0, 10, 1),
-#'     limits = c(0, 10)
+#'   # the most basic function call
+#'   grouped_ggwithinstats(
+#'     data             = filter(bugs_long, condition %in% c("HDHF", "HDLF")),
+#'     x                = condition,
+#'     y                = desire,
+#'     grouping.var     = gender,
+#'     type             = "np", # non-parametric test
+#'     # additional modifications for **each** plot using `{ggplot2}` functions
+#'     ggplot.component = scale_y_continuous(breaks = seq(0, 10, 1), limits = c(0, 10))
 #'   )
-#' )
+#' }
 #' }
 #' @export
 
