@@ -55,10 +55,10 @@ onesample_df <- function(data, x, y, k = 2L, ...) {
     mutate(
       .label = paste0(
         "list(~chi['gof']^2~", "(", df, ")==", format_value(statistic, k),
-        ", ~italic(p)=='", format_num(p.value, k, p.value = TRUE),
+        ", ~italic(p)=='", format_value(p.value, k, ),
         "', ~italic(n)==", .prettyNum(counts), ")"
       ),
-      .p.label = paste0("list(~italic(p)=='", format_num(p.value, k, TRUE), "')")
+      .p.label = paste0("list(~italic(p)=='", format_value(p.value, k), "')")
     ) %>%
     ungroup()
 }
