@@ -53,8 +53,8 @@ test_that(
       )$expression[[1]]
 
     # checking plot labels
-    expect_identical(pb$plot$labels$caption, p_cap)
-    expect_identical(pb$plot$labels$subtitle, p_subtitle)
+    expect_equal(pb$plot$labels$caption, p_cap)
+    expect_equal(pb$plot$labels$subtitle, p_subtitle, ignore_attr = TRUE)
     expect_snapshot(within(pb$plot$labels, rm(subtitle, caption)))
   }
 )
@@ -97,7 +97,7 @@ test_that(
       )$expression[[1]]
 
     # testing data and annotations
-    expect_identical(pb$plot$labels$subtitle, p_subtitle)
+    expect_equal(pb$plot$labels$subtitle, p_subtitle, ignore_attr = TRUE)
     expect_snapshot(within(pb$plot$labels, rm(subtitle)))
   }
 )
@@ -138,7 +138,7 @@ test_that(
     set.seed(123)
     expect_snapshot(pb$data[[1]])
 
-    expect_identical(pb$plot$labels$subtitle, p_subtitle)
+    expect_equal(pb$plot$labels$subtitle, p_subtitle, ignore_attr = TRUE)
     expect_snapshot(within(pb$plot$labels, rm(subtitle)))
   }
 )
@@ -173,7 +173,8 @@ test_that(
       data = dplyr::filter(ggplot2::msleep, conservation == "lc"),
       x = sleep_total,
       y = sleep_cycle,
-      type = "bayes"
+      type = "bayes",
+      top.text = "source: ggplot2 package"
     )$expression[[1]]
 
     # check just the names and dims and not the actual values
@@ -181,7 +182,7 @@ test_that(
     expect_snapshot(purrr::map(pb$data, names))
     expect_snapshot(purrr::map(pb$data, dim))
 
-    expect_identical(p$labels$subtitle$expr, p_subtitle)
+    expect_equal(pb$plot$labels$subtitle, p_subtitle, ignore_attr = TRUE)
   }
 )
 
@@ -249,7 +250,7 @@ test_that(
       )$expression[[1]]
 
     # checking captured messages
-    expect_identical(p_sub, fun_sub)
+    expect_equal(p_sub, fun_sub)
   }
 )
 
@@ -257,6 +258,7 @@ test_that("plots are rendered correctly - ggscatterstats", {
   skip_on_cran()
   skip_if_not_installed("vdiffr")
   skip_if(getRversion() < "4.1")
+  skip_if(getRversion() >= "4.2")
 
   # vdiffr tests --------------------------------
 
